@@ -46,8 +46,10 @@ def _call_signature(
         if arg not in SPECIAL_ARGS and arg not in kwargs:
             raise ParserError(
                 f"{terminal_colors.RED}{terminal_colors.BOLD}"
-                f"`{plugin_name}` requires the argument "
-                f"`{arg}` in your configuration file."
+                f"The plugin `{plugin_name}` requires the argument "
+                f"`{arg}` in your configuration file. "
+                "Run the command `webviz docs` if you want "
+                "to see documentation of the plugin."
                 f"{terminal_colors.END}"
             )
 
@@ -85,7 +87,9 @@ def _call_signature(
             raise ParserError(
                 f"{terminal_colors.RED}{terminal_colors.BOLD}"
                 f"Unrecognized argument. `{plugin_name}` "
-                f"does not take an argument `{arg}`."
+                f"does not take an argument `{arg}`. "
+                "Run the command `webviz docs` if you want "
+                "to see documentation of the plugin."
                 f"{terminal_colors.END}"
             )
 
@@ -107,7 +111,9 @@ def _call_signature(
                         f"given to `{plugin_name}` is "
                         f"of type `{type(kwargs[arg]).__name__}`. "
                         f"Expected type "
-                        f"`{argspec.annotations[arg].__name__}`."
+                        f"`{argspec.annotations[arg].__name__}`. "
+                        "Run the command `webviz docs` if you want "
+                        "to see documentation of the plugin."
                         f"{terminal_colors.END}"
                     )
             # Typechecking typing classes does not work in python 3.7
@@ -122,6 +128,15 @@ def _call_signature(
     )
     if deprecated_plugin:
         deprecation_warnings.append(deprecated_plugin.short_message)
+        warnings.warn(
+            f"""Plugin '{plugin_name}' has been deprecated.
+------------------------
+{deprecated_plugin.short_message}
+===
+{deprecated_plugin.long_message}
+""",
+            FutureWarning,
+        )
 
     deprecations = _ds.DEPRECATION_STORE.get_stored_plugin_argument_deprecations(
         getattr(webviz_config.plugins, plugin_name).__init__
@@ -137,7 +152,7 @@ def _call_signature(
             if deprecation.argument_name in kwargs_including_defaults.keys():
                 deprecation_warnings.append(deprecation.short_message)
                 warnings.warn(
-                    """Deprecated Argument: {} with value '{}' in method {} in module {}
+                    """Deprecated Argument: '{}' with value '{}' in plugin '{}'
 ------------------------
 {}
 ===
@@ -145,8 +160,7 @@ def _call_signature(
 """.format(
                         deprecation.argument_name,
                         kwargs_including_defaults[deprecation.argument_name],
-                        deprecation.method_name,
-                        getattr(deprecation.method_reference, "__module__"),
+                        plugin_name,
                         deprecation.short_message,
                         deprecation.long_message,
                     ),
@@ -164,7 +178,7 @@ def _call_signature(
             if result:
                 deprecation_warnings.append(result[0])
                 warnings.warn(
-                    """Deprecated Argument(s): {} with value '{}' in method {} in module {}
+                    """Deprecated Argument(s): '{}' with value(s) '{}' in plugin '{}'
 ------------------------
 {}
 ===
@@ -176,8 +190,7 @@ def _call_signature(
                             for key, value in kwargs_including_defaults.items()
                             if key in deprecation.argument_names
                         ],
-                        deprecation.method_name,
-                        getattr(deprecation.method_reference, "__module__"),
+                        plugin_name,
                         result[0],
                         result[1],
                     ),
